@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
 """Event loop implementation."""
-from __future__ import absolute_import, unicode_literals
 
 import errno
 from contextlib import contextmanager
+from queue import Empty
 from time import sleep
 from types import GeneratorType as generator  # noqa
 
-from kombu.five import Empty, python_2_unicode_compatible, range
 from kombu.log import get_logger
 from kombu.utils.compat import fileno
 from kombu.utils.eventio import ERR, READ, WRITE, poll
@@ -51,8 +49,7 @@ def set_event_loop(loop):
     return loop
 
 
-@python_2_unicode_compatible
-class Hub(object):
+class Hub:
     """Event loop object.
 
     Arguments:
@@ -128,7 +125,7 @@ class Hub(object):
         self.call_soon(_raise_stop_error)
 
     def __repr__(self):
-        return '<Hub@{0:#x}: R:{1} W:{2}>'.format(
+        return '<Hub@{:#x}: R:{} W:{}>'.format(
             id(self), len(self.readers), len(self.writers),
         )
 
@@ -259,7 +256,9 @@ class Hub(object):
         # To avoid infinite loop where one of the callables adds items
         # to self._ready (via call_soon or otherwise).
         # we create new list with current self._ready
-        for item in list(self._ready):
+        todos = list(self._ready)
+        self._ready = set()
+        for item in todos:
             item()
 
     def _discard(self, fd):
